#
# spec file for package platformsh-cli
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           platformsh-cli
Version:        3.40.5
Release:        1.1
Summary:        Tool for managing Platform.sh services from the command line
# See licenses.txt for dependency licenses.
License:        MIT
Group:          Productivity/Networking/Web/Servers
Url:            https://github.com/platformsh/platformsh-cli
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-vendor.tar.xz
Source10:       extensions.php
Source11:       extensions.txt
Source12:       licenses.txt
Source13:       update.sh
BuildRequires:  xz
Requires:       php >= 5.5.9
Suggests:       php-curl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
The Platform.sh CLI is the official command-line interface for Platform.sh.
Use this tool to interact with Platform.sh projects, and to build them
locally for development purposes.

%prep
# -a 1: unpack Source1 vendor tarball
%setup -q -a 1

%build
find . -name ".travis.yml" -delete

%install
# install drush source
install -d -m 0755 . %{buildroot}%{_datadir}/%{name}
cp -r * %{buildroot}%{_datadir}/%{name}

# link to executable in bindir
mkdir -p %{buildroot}%{_bindir}
ln -s %{_datadir}/%{name}/bin/platform %{buildroot}%{_bindir}/platform

# link to bash complete script
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
ln -s %{_datadir}/%{name}/shell-config.rc %{buildroot}%{_sysconfdir}/bash_completion.d/platform.sh.complete.sh

%files
%defattr(-,root,root,-)
%{_datadir}/%{name}
%{_bindir}/platform
%{_sysconfdir}/bash_completion.d/platform.sh.complete.sh

%changelog
* Tue Mar 12 2019 jimmy@boombatower.com
- Update to version 3.40.5:
  * Release v3.40.5
  * Disable pcre.jit in tunnel:open command to work around PHP bug #77260 (#786)
  * Update security test script
* Tue Feb 26 2019 jimmy@boombatower.com
- Update to version 3.40.4:
  * Release v3.40.4
  * Block snapshot:restore with --target for legacy regions
  * fix(mongo): database authentification
  * Release v3.40.3
  * Attempt to find the app root via SSH for Enterprise environments (#781)
  * Fix "Service not found: " error in "db:" commands where the service is not known
* Mon Feb 18 2019 jimmy@boombatower.com
- Update to version 3.40.2:
  * Release v3.40.2
  * Fix default for single relationship when choosing a service
  * Update dependencies (Symfony 3.4.19 -> 3.4.22)
* Mon Feb 18 2019 jimmy@boombatower.com
- Update to version 3.40.1:
  * Release v3.40.1
  * Fix --relationship option with trailing .0 when selecting from multiple endpoints
  * Account for integrated Enterprise environments whose deployment schema information isn't accurate
  * Ensure the service name is in the relationship array
* Fri Feb 15 2019 jimmy@boombatower.com
- Update to version 3.40.0:
  * Release v3.40.0
  * Use a different Drush alias root for site-local versions 8 or 9 (#777)
  * Fix non-interactive choice default handling
  * Fix non-interactive choice questions with no default should return null instead of erroring
  * Make db:size schema agnostic but warn about inaccessible schemas
  * Filter schemas by endpoint privileges
  * Present a choice between schemas
  * Include the service name and schema in the dump filename
  * Add --schema option to db:dump and db:sql
  * Always include a line break after choose()
  * Fix checkout command when there is only one branch
  * Fix Drush lock files not being used
  * Add some 3-letter aliases
  * Remove experimental "server" commands from README
* Fri Jan 18 2019 jimmy@boombatower.com
- Update to version 3.39.0:
  * Release v3.39.0
  * Add tunnel:single command: allow opening a tunnel without posix/pcntl (#768)
  * Drush 9 compatibility: move alias auto-remove key under "options"
  * Remove Drush 9-beta compatibility
  * Fix: login does not sufficiently log out from old account (#770)
  * Account for differing app roots in Drush aliases
  * Unused function
  * Release v3.38.1
  * Fix incorrect "You cannot use both the <environment> argument and the --environment option" error in environment:activate command
* Wed Jan  9 2019 jimmy@boombatower.com
- Update to version 3.38.0:
  * Release v3.38.0
  * Fix addOption arguments in snapshot:restore
  * Allow restoring snapshots to another environment (#735)
  * Sort interactive project/environment choices alphabetically
  * Update README.md [skip changelog]
  * Deduplicate role option description [skip changelog]
  * Separate user:add and user:update command help
  * [environment:list] Define "created" and "updated" columns
  * [environment:list] Fix "Name" column should always have been "Title"
  * Also support environment titles of 0
  * Fix: environments with an empty name (e.g. '0') not being recognized
  * [certificate:list] Add --pipe-domains option
  * [certificate:list] Add --exclude-domain option
  * [certificate:list] Add certs alias
  * Remove interactivity check from installer (#765)
  * [certificate:list] Define `domains` column
  * [certificate:list] Filter on --no-expired by default; add --ignore-expiry option for previous behavior
  * Fix inline documentation in user:list command
  * Run tests in PHP 7.3 (Travis) (#764)
* Fri Dec 28 2018 jimmy@boombatower.com
- Update to version 3.37.2:
  * Release v3.37.2
  * [worker:list] Display project and environment name/ID
  * [snapshot:list] Display project and environment name/ID
  * [route:list] Display project name/ID
  * [domain:list] Display project name/ID
  * [activity:list] use api() method [skip changelog]
  * [user:list] Display project name/ID
  * Alias "python3" dependencies type to use pip
  * Define "path" column in mount:list command
  * Fix table CSV test
  * Revert csv/tsv output to use LF instead of CRLF line breaks
  * [activity:list] Better explanation of the selected environment/project
  * Parse project URLs from the beta unified-UI (#761)
* Thu Nov 29 2018 jimmy@boombatower.com
- Update to version 3.37.1:
  * Release v3.37.1
  * [mount:size] Fix capacity calculation (should show %% of total space, instead of %% of "available")
* Wed Nov 28 2018 jimmy@boombatower.com
- Update to version 3.37.0:
  * Release v3.37.0
  * Update dependencies (mostly Symfony v3.4.6 to v3.4.19)
  * [auth:password-login] Fail if password input cannot be hidden
  * Allow loading more than 10 snapshots via --limit (#758)
  * [environment:branch] set the remote only for new branches (#760)
  * Fix #755: Add Instruction how to install on windows
  * Name "role" column in user:list command
  * Only allow a single name for a table column (key or header)
  * Name "disk" column in service:list command
  * Add non-default "updated_at" column to domains:list command
  * Add non-default "disk" and "size" columns to app:list command
  * Add non-default "host" column to project:list command
  * Add custom CSV formatter, to make csv/tsv table output cleaner
  * Add --columns option for all tables
  * Remove `sudo: false` as required by Travis-CI
  * Avoid wrapping dates in commit:list
  * Mark some more tests as slow, but do not allow them to fail
  * Update list of allowed SSH key algorithms
  * Avoid repeating session dir path
  * Simplify logout command and remove confirmation step
* Mon Nov 12 2018 jimmy@boombatower.com
- Update to version 3.36.0:
  * Release v3.36.0
  * Fix dev version [skip changelog]
  * Use heredoc for command help
  * Deprecate the --type option in integration:update
  * Consistent formatting for validation errors from other integration commands
  * Add integration:validate command
  * Fix further source of 'Not logged in' errors immediately after login
  * Do not cache commit API metadata
  * Fix alpha UI URLs for environments in web command
  * Release v3.35.4
  * Fix occasional LoginRequiredException at the end of login
  * Fix logout check for other sessions
  * Support forcing color off via PLATFORMSH_CLI_NO_COLOR=1 or NO_COLOR=1
  * [self:release]: remove release confirmation step [skip changelog]
* Fri Oct 12 2018 jimmy@boombatower.com
- Update to version 3.35.3:
  * Release v3.35.3
  * Revoke this session's tokens pro-actively on logout
  * multi: ignore blank lines in the project ID list
* Fri Oct  5 2018 jimmy@boombatower.com
- Update to version 3.35.2:
  * Release v3.35.2
  * Do not prompt for checkout in branch command if it won't be possible
  * Small refactor of commit:list [skip changelog]
  * Fix infinite loop in commit:list command (when trying to go back before a root commit)
  * Get service name from config for Bitbucket hooks
  * Friendlier commit:get examples
* Thu Sep 27 2018 jimmy@boombatower.com
- Update to version 3.35.1:
  * Release v3.35.1
  * Fix "p" alias in shell-config-bash.rc
  * Another release note tweak
  * Tweak release notes minimum version
  * Release v3.35.0
  * [variable:update]: Allow changing the value of a project-level sensitive variable
  * Allow listing commits without specifying an environment
  * Remove unnecessary $i
  * Iterate through all parents in commit:list, and go back to author date
  * Add explanations for "Operation not available" on environment actions (#750)
  * Use "id" instead of "uuid" to refer to user IDs
  * Add alias p=platform (#749)
  * Add commit:list (commits) and commit:get commands for viewing commits
  * Handle ~ revision spec in the --commit option
  * Add --commit option to "repo" commands (#748)
  * Additional help for mount:size
  * Clean up --pipe output in user:get
  * Rename UserRoleCommand -> UserGetCommand
  * Box syntax simplification
  * Add Bitbucket integration (#480)
  * Show hidden service commands
  * Tweak to prefix option display in variable:create
  * List required extensions in composer.json (#746)
  * Unused import
  * Remove extra whitespace [skip changelog]
  * Fix drush alias group name prepending bug
  * Fix installer test script to use correct manifest
* Tue Sep 11 2018 jimmy@boombatower.com
- Update to version 3.34.3:
  * Release v3.34.3
  * self:release: confirm changelog before building Phar
  * Update Guzzle for PHP 7.3 compatibility
  * Use pipenv instead of awscli in build deps test (for Travis)
  * Test the installer via Travis
  * Fix undefined constant STDOUT in the installer
  * Fix undefined constant STDOUT in the installer
  * Update list of default regions, take #2 (#742)
  * Update list of default regions. (#741)
* Thu Sep  6 2018 jimmy@boombatower.com
- Update to version 3.34.2:
  * Release v3.34.2
  * Always refresh resources when an operation is not available (#740)
  * Fix --start option in activity:list
  * Prefer .bash_profile over .bashrc on OS X
  * Make the installer interactive if possible
* Sat Jul 21 2018 jimmy@boombatower.com
- Update to version 3.34.1:
  * Release v3.34.1
  * Fix --pipe option in the environment:ssh (ssh) command
  * Wording tweak for sync --rebase
* Thu Jul 19 2018 jimmy@boombatower.com
- Update to version 3.34.0:
  * Release v3.34.0
  * Add --worker option to the SSH command (#736)
  * Remove legacy API workaround in integration:update
  * Add --depth option to project:get (get) command (#715)
  * Add --rebase option to the environment:synchronize (sync) command. (#714)
  * Add --prune-branches option for github and gitlab integrations (#723)
  * Update user commands for upstream API fix (improves performance) (#718)
  * Add service:list (services) command (#731)
  * [db:dump] Add --no-owner to pg_dump command (#733)
  * [self:install] Format source argument with ./ if it is a basename
  * Fix --all option in list command
  * [self:install]: prefer .bashrc over .bash_profile
  * Installer: fix undefined constant when run through stdin to PHP
  * Fix colorization in installer
* Wed Jun 27 2018 jimmy@boombatower.com
- Update to version 3.33.6:
  * Release v3.33.6
  * Installer improvements (#730)
  * Make environment labels consistent (#729)
  * Refactor mount:size command; add --refresh option
  * Get current deployment from cache
* Fri Jun 22 2018 jimmy@boombatower.com
- Update to version 3.33.5:
  * Release v3.33.5
  * Support Integrated UI environmments in environment:logs (log) command (#728)
  * Fix exception in mount:size commmmand on some regions
* Mon Jun 18 2018 jimmy@boombatower.com
- Update to version 3.33.4:
  * Release v3.33.4
  * Identifier: extract cluster name even from failed responses
  * Fix the web root symlink for a top-level app in a multi-app project
  * Remove hidden commands from autocomplete
  * Browser login: print shell command when in very-verbose mode
* Wed Jun  6 2018 jimmy@boombatower.com
- Update to version 3.33.3:
  * Release v3.33.3
  * Complete installation without an existing shell config file (#725)
  * Fix uninitialized string offset warning in YamlParser
  * Change default db:dump filename to use the environment's machine name
* Tue May 22 2018 jimmy@boombatower.com
- Update to version 3.33.2:
  * Release v3.33.2
  * Fix command not found problem in crons
  * Allow color in composer install
  * Revert "Installer: use manifest direct from GitHub"
  * Installer: use manifest direct from GitHub
  * Slack channel can be an ID (#719)
* Thu May 17 2018 jimmy@boombatower.com
- Update to version 3.33.1:
  * Release v3.33.1
  * Work around regression caused by previous commit 6659d65
* Wed May 16 2018 jimmy@boombatower.com
- Update to version 3.33.0:
  * Release v3.33.0
  * Add --sensitive option for project-level variables (#716)
  * Add mount:size command (#713)
  * Add a README warning about debug mode [skip changelog]
  * Clear environment/project caches after a 403 error
  * Increase prominence of warning in db:size (#712)
  * Ignore automatic updates if the Phar is not writable
* Mon May 14 2018 jimmy@boombatower.com
- Update to version 3.32.5:
  * Release v3.32.5
  * Installer: improvements to environment configuration snippet (#711)
  * Avoid false positives when recommending .gitignore in Drupal vanilla sites
  * Allow a timezone to be configured for the CLI in application.timezone
  * Improve "No services found" message and ignore relationships without a scheme.
* Mon May  7 2018 jimmy@boombatower.com
- Update to version 3.32.4:
  * Release v3.32.4
  * Statically cache project users (speeds up commands like 'user:get')
  * Fix descriptions for activity messages that contain /
  * Raise default updates check interval to 7 days
  * [project:set-remote] ignore the "current" project if it does not exist
* Thu Apr 19 2018 jimmy@boombatower.com
- Update to version 3.32.3:
  * Release v3.32.3
  * Correct fix for snapshot:restore and variable:delete bug 😳
  * [self:release] fix release download URL [skip changelog]
  * Release v3.32.2
  * [self:release] Use temp dir for phar file [skip changelog]
  * Fix invalid type bug that broke 2 commands: variable:delete and snapshot:restore
  * [project:get] ... and check for all heads [skip changelog]
  * [project:get] Fix check for repository existence (do not assume a default HEAD)
  * Fix: allow more than one / in a GitLab project name (#708)
  * [activity:log] show progress bar if possible
  * [self:install] Detect ZSH more liberally when finding a config file
* Fri Apr 13 2018 jimmy@boombatower.com
- Update to version 3.32.1:
  * Release v3.32.1
  * Unused closure import [skip changelog]
  * Fix shell arg escaping with remote commands for Windows (#707)
  * Update PhpUnit to best version for PHP requirements
  * Improve apps error message for inactive environents
  * [self:release] allow customizing the download URL [skip changelog]
  * [activity:get] calculate duration relative to now for incomplete activities
* Tue Apr 10 2018 jimmy@boombatower.com
- Update to version 3.32.0:
  * Release v3.32.0
  * Add MongoDB commands: mongo, mongoexport, mongodump, and mongorestore (#703)
  * Word-wrap option descriptions to the terminal width
  * [user:add] Add a wildcard for the environment ID
  * Parse !include tags when loading a YAML file (#701)
  * Try to refresh an environment before giving an "Operation not available" error
  * Fix user:role `--pipe` option when getting an environment role
  * TimezoneUtil: Suppress PHP's timezone warning
* Wed Apr  4 2018 jimmy@boombatower.com
- Update to version 3.31.6:
  * Release v3.31.6
  * [self:release] Validate version number against the last one [skip changelog]
  * Use PhpExecutableFinder to execute 'php' commands
  * Apply same "reset client" fix to auth:password-login
  * [auth:browser-login] Reset API client after login
  * [auth:browser-login] Log in again if an API request fails with 400 or 401
* Sat Mar 31 2018 jimmy@boombatower.com
- Update to version 3.31.5:
  * Release v3.31.5
  * [bot] add --party and --parrot options
  * Add application.date_format to README
  * Add application.date_format config option
  * Smarter environment cache
* Thu Mar 29 2018 jimmy@boombatower.com
- Update to version 3.31.4:
  * Release v3.31.4
  * [project:info] show 'git' and 'url' in the property list
  * [environment:drush] Use deployment routes to find a site URL
  * Allow accounts API URL to not terminate with / [skip changelog]
  * Remove CHANGELOG.md: use /releases instead for change logs
  * [self:release] use GitHub commits API to get the tag SHA [skip changelog]
  * Test 'drush' command for Drush functionality before using
* Tue Mar 27 2018 jimmy@boombatower.com
- Update to version 3.31.3:
  * Release v3.31.3
  * Document experimental_commands key [skip changelog]
  * Allow all_experiments to come first [skip changelog]
  * Add mechanism to define commands as experimental [skip changelog]
  * [self:release] Improve changelog generation [skip changelog]
  * Symfony dependencies update
  * [self:install] Only include shell-config if it exists; update config snippet automatically
  * [activity:get] Do not require an environment if an ID is provided
  * Adapt wrapWithDecoration for literal tags
  * Release v3.31.2
  * Update API client [skip changelog]
  * Improve variable creation
  * Decode HTML entities in activity descriptions
  * Release v3.31.1
  * Fix decoration when single element wraps onto multiple lines
* Tue Mar 20 2018 jimmy@boombatower.com
- Update to version 3.31.0:
  * Release v3.31.0
  * Fix bug: boolean false fields omitted when creating integrations
  * Re-implement line wrapping to account for trimming
  * [multi] Accept URLs as project identifiers
  * Formatted text improvements
  * Fix wrapping of indented cells
  * Wrap cell contents while preserving decoration
  * Display username in already-logged-in message
  * [build] Run post_deploy hooks if --run-deploy-hooks option is used
  * Add project:clear-build-cache command
  * Less wordy
  * Fix requiring environment when level not specified
  * Add short variable level option, e.g. '-l p'
  * Recommend other variable commands
  * Removing duplicate message
  * Fix prefixing
  * Add <name> argument to variable:create
  * Clean up and pass on wait options
  * Handle variables at both levels
  * Update README command list
  * Mark some variable commands as deprecated
  * Add --enabled option for variable:create and variable:update
  * Display variables on create or update
  * Add --property option to variable:get
  * Add variable:list command
  * Modify variable:get so it works with project or environment level variables
  * Add variable:update command
  * Add variable:create command
  * Update API client: avoid loading individual activiites when description property is missing
  * Fix wrapping of text decoration in adaptive table
  * Un-hide some commands
  * [auth:browser-login] Expand port range; add detailed port error message; simplify port validation
  * [subscription:info] Update command description
  * [list] Add --all option to show hidden commands
  * Trim whitespace from API error messages
  * Limit the amount of projects that can trigger a project choice
  * Release v3.30.1
  * [environment:push] Fix inverse --no-wait/--wait logic
  * Allow overriding the last version and release branch in self:release [skip changelog]
  * Always use the deployment API for the app list
  * [self:release] Update changelog automatically if release-changelog is out of date [skip changelog]
  * [environment:push] Fix inverse --no-wait/--wait logic
  * Allow overriding the last version and release branch in self:release [skip changelog]
  * Always interact where possible to ask for the project / environment (#690)
  * Always use the deployment API for the app list
  * [self:release] Update changelog automatically if release-changelog is out of date [skip changelog]
* Fri Mar  2 2018 jimmy@boombatower.com
- Update to version 3.30.0:
  * Release v3.30.0
  * [self:release] Support editing the changelog [skip changelog]
  * Format activity descriptions
  * Print questions even when non-interactive
  * Add --wait option and shouldWait() cron/hook detection
  * Update redeploy warning
  * Add redeploy command
  * [self:install] Ensure directory exists when creating shell-config.rc
  * Ensure GitLab/GitHub hooks have the right events (#687)
  * [activity:get] do not require an environment with --all and a partial ID
  * [login] Mention --force option
  * Fix release SHA-256 hash
* Tue Feb 20 2018 jimmy@boombatower.com
- Update to version 3.29.2:
  * Release v3.29.2
  * Move release logic out of self:build
  * Update dependencies
  * [self:stats] Add --page option [skip changelog]
* Mon Feb 19 2018 jimmy@boombatower.com
- Update to version 3.29.1:
  * Release v3.29.1
  * Add self:release command
  * Fix array to string conversion in project identifier
  * [auth:browser-login] Always show help message
  * [activity:get] [activity:log] Match partial activity IDs
  * New line tweak [skip changelog]
  * Add self:stats command
  * [project:create] Get the list of regions dynamically
  * [activity:log] Do not require ANSI check for polling/logging
  * Merge metadata back from master [skip changelog]
* Mon Feb 12 2018 jimmy@boombatower.com
- Update to version 3.29.0:
  * Release v3.29.0
  * [db:dump] Remove --no-autocommit and simplify mysqldump args (#683)
  * New lines in user:role to match user:add [skip changelog]
  * Refactoring of user:add [skip changelog]
  * Use getUsers() instead of getUser() in user:add [skip changelog]
  * [user:add] [user:update] expand interactive help text
  * Add `user:get` command (aliased to and deprecating `user:role`)
  * [user:add] Improve `user:add` command to allow setting roles on all environments
  * Expand redeploy warning to recommend "vset"
  * Back to -dev
  * [activity:get] Check for empty started_at when calculating duration
  * [service:redis-cli] Recommend "redis info" command
  * Merge CHANGELOG and manifest.json updates from master
* Wed Jan 31 2018 jimmy@boombatower.com
- Update to version 3.28.0:
  * Update manifest for rebuild of v3.28.0
  * Release v3.28.0
  * Update dependencies (mainly Symfony 3.4.2 -> 3.4.4)
  * Add activity state in log
  * Fix inverted requirement of -e/-a in activity:list and activity:log
  * Add activity duration and simplify log output
  * Add activity:get command
  * Add --date-fmt option to `activity:list` and `snapshot:list`.
  * Respect date.timezone and allow TZ env var
  * Fix existing aliases being prefixed with "@" (#679)
  * Avoid fatal if an InvalidConfigException is encountered during updateDrushAliases()
  * Use -t instead of RequestTty, for OpenSSH <5.9
* Wed Jan 24 2018 jimmy@boombatower.com
- Update to version 3.27.2:
  * Release v3.27.2
  * [self:build] Ignore certain commits from changelog (with [skip changelog])
  * Fix: 'Invalid refresh token' message interception shouldn't check the request for oauth2
  * Update list output in README.md
  * Fix link
  * Expand API token info in README.md
  * [project:create] add detailed help
  * [project:create] be stricter about check interval
  * Minor correction to 7d41dce97bd5fed4c1f4cda3ca84e1f6a13acb62
  * [subscription:info] allow passing a subscription ID directly
  * [project:create] show project ID if possible even after failure
* Tue Jan 23 2018 jimmy@boombatower.com
- Update to version 3.27.1:
  * Release v3.27.1
  * [project:create] increase check timeout and make it configurable
  * self:build: check for boolean output from git command
  * Note login_method in README.md
  * Note login_method can be overriden
* Fri Jan 19 2018 jimmy@boombatower.com
- Update to version 3.27.0:
  * Release v3.27.0
  * Print changelog in self:build
  * Allow override of application.login_method in user config
  * Set --build-pull-requests-post-merge false by default (GitHub integrations)
  * Respect --no-wait in environment:init, and clear environment cache
  * Allow custom scheme in browser login
  * Fix browser login boolean mistake..
  * Explain failed deletion
  * Delegate project:delete access to the API
  * Link directly to latest release
  * auth:browser-login: always display URL in case the default browser did not work
  * Support colors via CLICOLOR_FORCE in final section of installer
  * Use browser login by default (#672)
  * Move disabled_commands under application in config.yaml
  * Add help in auth:browser-login and auth:login explaining alternatives
  * Better Windows description
  * Update README.md
  * Update to Symfony 3.4.2
  * Browser login: markup improvements
  * Update CHANGELOG.md for v3.26.1
* Fri Dec 29 2017 jimmy@boombatower.com
- Update to version 3.26.1:
  * Release v3.26.1
  * Update CHANGELOG.md
  * Move chmod() to install section of installer
  * Find latest version regardless of mode in self:build
  * Restore Phar moving to installer
  * Remove duplicate message in self:install
  * Add auth:browser-login command (#669)
  * Add snippet markers in shell config
  * Remove old update notes
  * Remove v2 from manifest.json
  * Add usage help at the end of self:install
  * Installer: just invoke self:install
  * Refactor shell config into separate files
  * Rename all_features to all_experiments
  * Add all_features flag
  * Update default D7 settings files
  * Unused code
  * Remove any direct use of remote_env_vars service
  * Fix route:get options list
  * Switch route:get to using deployments API (instead of SSH)
  * Update CHANGELOG.md for v3.26.0
  * Fix manifest update notes version constraints
  * Remove extra quotes from git changelog
  * Fix manifest update notes version constraints
* Thu Dec 21 2017 jimmy@boombatower.com
- Update to version 3.26.0:
  * Release v3.26.0
  * Remove extra quotes from git changelog
  * Fix config normalization when there is an empty locations array
  * Skip updates check if the Phar file is not writable
  * Remove different coloration for local commands (there are so few listed)
  * Recommend --no-wait if snapshot:create is run in a non-TTY
  * Support remote envs in app:list
  * Remove unused LocalApplication::getApplication()
  * Suggest project:set-remote in RootNotFoundException
  * Add app names from cached SSH URLs for autocompletion
  * Refactor to dedupe getDocumentRoot() methods
  * Update CHANGELOG.md for v3.25.1
  * Generate changelog based on master
  * Show worker commands
  * Use PLATFORM_DOCUMENT_ROOT if available
  * Cache the current deployment
  * Add worker:list command
  * Use deployments API for remote app information
  * Auto-ensure webhooks on GitHub and GitLab integrations (#665)
  * Be stricter about when to use $_ENV, when getting parent variables for PHP <7.1
  * The default CWD for a Git repository should be null, not .
* Fri Dec 15 2017 jimmy@boombatower.com
- Update to version 3.25.1:
  * Release v3.25.1
  * Ensure we do not pass an invalid CWD to Symfony Process
  * Identifier: Add short timeout on URL check
  * Remove var_dump()s
* Wed Dec 13 2017 jimmy@boombatower.com
- Update to version 3.25.0:
  * Rebuild v3.25.0
  * Remove var_dump()s
  * Release v3.25.0
  * Fix keychain app ID, and put whole feature behind a use_keychain flag
  * Add CHANGELOG.md
  * Save session data in the keychain on OS X (#663)
  * Clean up
  * Accept projects not in the user's list in multi command
  * Expose redis relationship/URL explicitly
  * Extended interactive question text
  * Omit non-required empty fields when adding an integration
  * Add --no-expired and --only-expired options to certificate:list
  * Ignore host in configured project not found message
  * Implement is_enabled on environment variables
  * Use getenv() in Config
  * Comments on DrushAlias
  * Unused import
  * Better 'project not found' message
  * Add redis command
  * Always inherit from the entire environment in PHP 7.1+
  * Add SSH_AGENT_PID to auto inherited environment variables
  * Add release notes for v3.24.0
* Thu Dec  7 2017 jimmy@boombatower.com
- Update to version 3.24.1:
  * Release v3.24.1
  * Make --excluded-environments not required
  * Release v3.24.0
  * Update Symfony dependencies to 3.4.1
  * More helpful repo:cat help
  * Raw output works fine if the argument is in the right place
  * Two bugs found by Scrutinizer
  * Cache not-found blobs and trees again
  * Cache git data per project (overwriting for new commit SHAs)
  * Backwards compatibility for db:size
  * self:build: write changelog if found
  * Drush service clean-up
  * Remove CWD workaround in Drush version check
  * Avoid ensureInstalled() when checking for Drush version
  * Fix Drush 9 alias not found check
  * Fix Drush 9 alias filename
  * Docblocks for Config
  * Add manifest.json and auto-update from self:build command
  * Comment services.yaml
  * Write curl debug output to STDERR, not STDOUT (Guzzle's default)
  * Cache trees
  * Update client for path matching and clean up
  * Remove project root requirement from db:size
  * Fix printing binary file contents in repo:cat
  * Better error messages for wrong file type
  * Rename repo:read-file to repo:cat
  * Cache much less
  * Add repo:ls command
  * Add repo:read-file command
  * Disable timeout explicitly for tunnel processes
  * Remove deprecated ProcessBuilder, preserving BC this time
  * Still use ProcessBuilder
  * Force Symfony Process >=3.4
  * Update to Symfony 3.4
  * Add -W alias to push --no-wait
  * Allow default mount target/source with --yes
  * Fix mounts options list
* Wed Nov 29 2017 jimmy@boombatower.com
- Update to version 3.23.0:
  * Release v3.23.0
  * mount commands: add --exclude and --include (#651)
  * Allow projects to be identified from their public website URL (#649)
  * Add excluded_environments option for webhooks (#652)
  * Add GitLab integration support (#647)
  * Improve mount commands output
  * Support new mount style
* Fri Nov 17 2017 jimmy@boombatower.com
- Update to version 3.22.3:
  * Release v3.22.3
  * Add a timeout to the Drush aliases check (#646)
  * Fix exit code from db:dump to respect errors (#645)
  * Normalize user-defined aliases too
* Wed Nov  8 2017 jimmy@boombatower.com
- Update to version 3.22.2:
  * Fix: Drush "root" argument must be absolute
  * Fix "root" argument for wrong alias type
* Fri Nov  3 2017 jimmy@boombatower.com
- Update to version 3.22.0:
  * Update Symfony dependencies from 3.3.9 to 3.3.10
  * Clean up Git service instantiation and destructor
  * Remove dead code from self:install
  * Rebuild warning should be redeploy
  * Avoid wrapping environment IDs when formatting is involved
  * Support .drush/site-aliases directory
  * Check whether Drush supports YAML alias files
  * Support YAML Drush aliases
  * Drush fixes for supporting version 9
  * Nest YAML aliases one level deeper
  * Remove problematic inline comments
  * Remove unnecessary method override
  * More cleanup
  * Remove drush argument for alias types
  * Use heredoc for file header
  * Refactor subdir move slightly
  * Fix tests and merge between PHP and YAML aliases
  * Unused import
  * Clean up move errors
  * Refactor getAliases() and getExistingAliases()
  * Refactor reading/setting alias group
  * Delete old YAML file when renaming group
  * Move aliases to new directory non-interactively
  * Use $app->isSingle() more often
  * Reduce failures in site-aliases migration
  * Fix merge of existing aliases
  * Remove support checks
  * Cleanup
  * Fail in local:drush-aliases if no Drupal apps are found
  * Test getDrupalApps()
  * Test that YAML aliases are created
  * Automatically write to drush.yml
  * Reduce hardcoding of .drush
  * Cleanup
  * Fix: new aliases should go in site-aliases subdir
  * project:info command: description should be writable
  * Use $app->getSourceDir() more often
  * Improve alias files migration
  * Avoid creating PHP alias files if not necessary
  * Distinguish less between Drush versions as global/local installs can differ
  * Simplify Drush version check
  * Use *.alias.yml for YAML aliases that more or less work
  * Remove a potentially confusing message
  * Make getExistingAliases() responsible for group order
  * Fix: YAML aliases should have host/user, not remote-host/remote-user
  * Normalize aliases for differences between PHP and YAML
  * Use getSshUrl() and getRouteUrls() when generating aliases
  * Add $app->getLocalWebRoot()
  * Cleanup
  * Use home-relative document root for remote Drush aliases
  * Prefer app-specific URLs in remote drush aliases
  * Revert "Prefer app-specific URLs in remote drush aliases"
  * Allow commands to be disabled through config
  * Use Drush aliases only if the local:drush-aliases command is enabled
  * Release v3.22.0
* Wed Oct 18 2017 jimmy@boombatower.com
- Update to version 3.21.0:
  * Fix installer bug writing multiple times to config
  * Fix installer bug writing multiple times to config
  * Use full namespace name in list command
  * add mount:list (lists) command
  * add mount:pull (mpull) and mount:push (mpush) commands
  * mount commands: use selected environment
  * mount commands: various improvements
  * Add a confirmation question and another interactive default for --target and --source
  * Rename mount commands
  * mount commands: restore --refresh option, add --delete option
  * List mounts as a table
  * Support logging in with a username (#636)
  * Fix: service dependencies of Filesystem did not get output class, initialized too early
  * Switch default output to ConsoleOutput
  * Release v3.21.0
* Fri Oct 13 2017 jimmy@boombatower.com
- Update to version 3.20.5:
  * Only show prune message once (follow up to #627)
  * GitHub integration: add flag for pull_requests_clone_parent_data (#623)
  * Add --no-clone-parent option to branch command (#630)
  * Add default from address for health.email integration (#632)
  * Fix infinite loop in Config::canWriteDir (#634)
  * Move Config::canWriteToDir to Filesystem::canWrite and add tests
  * Release v3.20.5
* Wed Sep 20 2017 jimmy@boombatower.com
- Update to version 3.20.4:
  * Exclude node_modules when using Finder - performance improvement
  * Add git prune help text when deleting a branch (#628)
  * Allow nested apps where the first app is at the top level
  * Update dependencies
  * Downgrade doctrine/cache for <7.1 compatibility
  * Warn when creating a .gz dump without --gzip
  * ... restore missing $projectRoot
  * ... remove unnecessary $project
  * Add new regions, and allow arbitrary regions or plans
  * Release v3.20.4
* Tue Sep 19 2017 jimmy@boombatower.com
- Update to version 3.20.3:
  * Clarify that merge affects the target
  * Halve automatic updates timeout
  * Installer: write to shell config if file does not yet exist
  * Installer: write to shell config if file does not yet exist
  * Allow using built-in server with non-PHP apps
  * Release v3.20.3
* Mon Sep 11 2017 jimmy@boombatower.com
- Update to version 3.20.2:
  * Update self:install command for consistency with installer
  * Remove Drush location hack for travis/phpunit
  * Find Drush in the CLI root if it is there via require-dev
  * Only include shell config if the shell is Bash or ZSH (#622)
  * Only include shell config if the shell is Bash or ZSH (#622)
  * Installer / self:install consistency
  * Check config dir existence in writability check
  * Release v3.20.2
* Mon Aug 28 2017 jimmy@boombatower.com
- Update to version 3.20.1:
  * Easy install on Platform.sh environments
  * No need to "source .environment"
  * Write to tmp if config directory is not available
  * Show ID of users (#618) (#619)
  * Docs can no longer be searched by URL
  * Use the local Drush if possible (#621)
  * Release v3.20.1
* Mon Aug 14 2017 jimmy@boombatower.com
- Update to version 3.20.0:
  * Switch to SHA-256 for file verification
  * Installer: remove BC code
  * Add pricing URL in create command
  * Add build_pull_requests_post_merge for github integrations (#612)
  * Clarify user:delete command (issue #615)
  * Alias --no-wait to -W
  * Add "health" integration types
  * Add summary format for health integrations
  * Match partial integration IDs
  * Unused import
  * Inspection tweaks
  * Avoid re-initializing application/command in CompletionCommand
  * Release v3.20.0
* Fri Aug 11 2017 jimmy@boombatower.com
- Update to version 3.19.1:
  * Populate project, environment, and app from environment variables where possible (#610)
  * Push command: do not activate by default in non-interactive mode
  * Travis update: add 7.2, fix hhvm build
  * Fix app choice for inactive environments
  * Sort routes choice in route:get
  * Add SHA-256 info in build command
  * Release v3.19.1
* Thu Jul 27 2017 jimmy@boombatower.com
- Update to version 3.19.0:
  * Fix description of --no-visible-runtime option
  * Make default_domain writable from project:info
  * Document saving tunnel info to the relationships variable
  * Add -u option to push command (#609)
  * Tiny text change (after commit 7866dd4)
  * Release v3.19.0
* Thu Jul  6 2017 jimmy@boombatower.com
- Update to version 3.18.0:
  * Promote "create" command
  * Unused imports
  * Make `create` command return project ID to stdout
  * Allow subscription info to be updated (#607)
  * Find SSH apps via the new pf:ssh: URLs in the API (#608)
  * Add --all option to `ssh` command
  * Fix BC for environments without pf:ssh: URLs
  * Add/restore interactive choice of environments in `get` command
  * ... only ask if >1 environment
  * Fix: ssh --all needs new lines
  * Leave "create" disabled by feature flag, until pricing estimation API improves
  * Release v3.18.0
* Tue May 30 2017 jimmy@boombatower.com
- Update to version 3.17.0:
  * Update console-form dependency
  * Docs search now needs rawurlencode()
  * Improve default Drush aliases on cloning (#603)
  * Add environment:init command
  * Release v3.17.0
* Fri May 19 2017 jimmy@boombatower.com
- Include development files in source list.
- Update to version 3.16.2:
  * Note how to run the CLI from source
  * Note how to run the CLI from source
  * Correct comment in ProjectGetCommand
  * Fix: certificate:delete command missing --no-wait option
  * Add --blobs to pg_dump
  * Installer: ignore errors in source/dot command in shell config
  * Better English in installer
  * Release v3.16.2
* Mon May 15 2017 jimmy@boombatower.com
- Update to version 3.16.1:
  * When creating a symlink, ensure both ends are real paths, if possible
  * Use improved makePathRelative elsewhere
  * Unused import
  * Use improved makePathRelative() in get command
  * ... typo
  * Release v3.16.1
* Thu May 11 2017 jengelh@inai.de
- Kill dot off summary. Fix other nonsense in description.
* Wed May 10 2017 jimmy@boombatower.com
- Update to version 3.16.0:
  * Remove old updates.last_checked default
  * Remove application.phar config value
  * Update self::install so it doesn't write to .profile
  * Fix filename if a directory is passed to the db:dump --file option
  * Stop timestamp being appended twice if --file is a directory
  * Add --directory option to db:dump
  * Use native search in docs command
  * Simplify DocsCommand
  * Note config.yaml snippet shows defaults
  * Update API client
  * Use starts_at paging to load more than 10 activities
  * Update API client for activity descriptions
  * Add project:curl command
  * Add auth:token command
  * Add -sS to project:curl
  * Release v3.16.0
* Wed May  3 2017 jimmy@boombatower.com
- Update to version 3.15.4:
  * Save update check time (to a place other than config)
  * Note State could be used more often
  * Simplify State->save()
  * Release v3.15.4
* Mon May  1 2017 jimmy@boombatower.com
- Update to version 3.15.3:
  * Fix wrong array keys in certificate:add
  * Trigger patch in platformsh/client package to actually apply
  * Document PLATFORMSH_CLI_TOKEN variable, with a warning
  * Do not check for updates immediately after install
  * Since we have the filename, the Phar can run directly
  * No need to write to user config for updates check
  * Release v3.15.3
* Mon May  1 2017 jimmy@boombatower.com
- Update to version 3.15.2:
  * Explain that auto-provisioned certificates can't be deleted
  * Show issuer in certificate:list
  * Allow partial match on ID in certificate:delete
  * Use RequestTty only for certain commands, when stdin is a tty
  * Add --raw option to sql command
  * SSH commands need to show errors
  * Downgrade Process, avoiding apparent segfault
  * Ensure running another command doesn't wipe necessary service data
  * Release v3.15.2
* Wed Apr 26 2017 jimmy@boombatower.com
- Update to version 3.15.1:
  * Add more contextual help in activity:list
  * Avoid formatting activity result in CSV/TSV output
  * Use pseudo-terminal for SSH
  * Remove CommandBase->isTerminal() in favour of Output->isDecorated()
  * Remove unnecessary 2>&1 from sql/drush over SSH commands
  * Use RequestTty and remove LogLevel hack
  * Update dependencies
  * ... security-checker still doesn't work via PHP in Travis
  * Rely on date_default_timezone_get() instead of UTC fallback
  * Update comment
  * Ssh issue with windows (#592)
  * Add certificate commands (#583)
  * Fix return value in certificate:add
  * Release v3.15.0
  * Fix certificate:delete confirm question
  * Release v3.15.1
* Mon Apr 17 2017 jimmy@boombatower.com
- Update to version 3.14.5:
  * Fix wrong QuestionHelper argument in "get" command
  * Remove two other non-type-hinted uses of getService()
  * Use ConsoleOutputInterface for stderr feature detection
  * Ensure target is realpath in symlink()
  * Release v3.14.5
* Sun Apr 16 2017 jimmy@boombatower.com
- Update to version 3.14.4:
  * Further improved timeout in project:create (blocking)
  * Move orphan logic up into buildEnvironmentTree
  * List 10 activities by default
  * More info with verbose output for a successful db:dump
  * Issue #585: Don't add bashisms to .profile
  * Make available plans/regions configurable
  * Fix URL opening on OS X (#586)
  * Release v3.14.4
* Wed Apr  5 2017 jimmy@boombatower.com
- Update to version 3.14.3:
  * Fix: existing file preventing file mount symlink
  * Run security check via curl in Travis for now
  * Avoid setting the upstream on the wrong branch
  * Further solidify setting an upstream for the right branch
  * Show if a snapshot failed in snapshot:list
  * Filter by successful snapshots in snapshot:restore
  * Display result (success/failure) for all activities
  * Improve timeout logic in project:create
  * Examples property can be private
  * Revert symfony/console to 3.2.4 to fix input validation
  * Release v3.14.3
* Wed Mar 29 2017 jimmy@boombatower.com
- Update to version 3.14.2:
  * Update dependencies
  * Remove "toolstack" concept, use "flavor"
  * Relative paths should not depend on files already existing
  * Remove makePathRelative() method (use Symfony directly)
  * Exception if query fails in db:size
  * Expose error output properly in db:size queries
  * Fix imports
  * Simplify error control; stop displaying two exceptions on bad connection
  * Release v3.14.1
  * Downgrade Process component to fix env var bug
  * Fail hard if the home directory is not found or valid
  * Release v3.14.2
* Wed Mar  1 2017 jimmy@boombatower.com
- Update to version 3.14.0:
  * Cache an empty relationships list
  * Add route-get command to view a resolved route to an environment
  * Rename route commands
  * Clarify URL choice in `url` command
  * Refactor code that reads remote environment variables
  * Fix cache clearing for env vars
  * Improve RemoteEnvVars documentation
  * Remove odd relationships dependency on @output
  * Fix integration option names
  * Release v3.14.0
* Thu Feb 23 2017 jimmy@boombatower.com
- Update to version 3.13.0:
  * Drupal settings: remind user to uncomment database config block
  * Update dependencies
  * Install build-time dependencies
  * Allow numerals in region domain components
  * Cleanup
  * Add an option to install dependencies globally
  * Remove yarn; fix npm install
  * Remove global deps for now, and downgrade missing package manager to a warning
  * Fix and test usage of PYTHONPATH
  * Add commands to run the PHP built-in web server
  * Update for CLI 3.x
  * Server: support custom variables prefixes
  * Locations (WIP)
  * Remove blank lines from log in server:start
  * Enable server commands via a feature flag
  * Update for new DIC
  * Implement static files rules and 'scripts' check
  * Refactor dead process check
  * Fix Drupal workaround
  * Open URLs for server:start
  * Fix APP_DIR setting
  * Incorporate routes
  * Use API client for project estimate
  * Update to Symfony 3.2.4
  * Release v3.13.0
* Wed Feb  8 2017 jimmy@boombatower.com
- Update to version 3.12.2:
  * Return failure code in activate command if the activity fails
  * Release v3.12.2
* Thu Feb  2 2017 jimmy@boombatower.com
- Update to version 3.12.1:
  * Comment mentions old method
  * More specific gitignore for Drupal vanilla
  * Allow updates.check to be overridden by an env var
  * Allow web command to be used with a non-existent environment
  * Improve 'get' when the user does not have access to master (#569)
  * Release v3.12.1
* Sat Jan 21 2017 jimmy@boombatower.com
- Update to version 3.12.0:
  * db:dump: add --bzip2 option
  * Tweaks
  * ...ok, no need for bzip2
  * Fix installer typo
  * Avoid $user as var name
  * Wrong comment
  * Use --no-color with git branch
  * Protect getVersion() methods
  * phpcs fixes
  * I believe there are missing double quotes there. (#561)
  * I believe there are missing double quotes there. (#561) (cherry-pick)
  * Add explicit platform.sh CLI name to SelfUpdater output  messages.
  * Add project:set-remote command
  * Update client
  * Stop enforcing an "origin" remote
  * Use the configurable application name
  * Add project variable commands to README
  * Installer: more precise shell config files preferences (#565)
  * master version has moved
  * Fix using integration:get command without an argument, when none exist
  * Set upstream in 'branch' only if the correct branch is checked out
  * Fix title in branch command
  * Clarify checkout command when creating new branch
  * Release v3.12.0
* Tue Jan 10 2017 jimmy@boombatower.com
- Update to version 3.11.0:
  * Offer to autocomplete the project ID for the directory in `platform get`
  * Use getEnvironment() in platform get, for consistency
  * ... and use the real environment ID
  * Add PropertyFormatter::displayData()
  * Test on 7.1
  * Refactor ProjectGetCommand
  * Expand possible site domains
  * Only show "Usage" after invalid input
  * Sensible error in self:build if phar.readonly is enabled
  * Document displayData() and tweak YAML formatting
  * Remove uses of deprecated getTerminalDimensions()
  * Allow extra regions to be used in create command
  * Allow debug/SSL config to be used with getEstimate()
  * Skip activate logic in push command if the target is master
  * Add --gzip option to db:dump
  * Account for hidden aliases in short command name
  * Hide a couple of aliases
  * Unify project option/argument syntax for project:delete and project:get
  * Remove uses of deprecated Completion::makeGlobalHandler()
  * Unused import
  * Refactor SQL connection options
  * Less repetition
  * environment:delete: Don't offer to delete the branch if --no-wait is specified
  * Fix pgsql arguments (--password doesn't allow a password value)
  * db:dump: add more advanced options
  * db:dump: warn if file is not excluded by Git
  * Release v3.11.0
* Wed Dec 28 2016 jimmy@boombatower.com
- Update to version 3.10.2:
  * Inject Git service for LocalProject
  * Push command: allow specifying the target branch
  * Disallow pushing an empty source
  * Verify source with Git
  * Show whether pushing to a new or existing env
  * Shell: use stdErr properly and make environment obvious in verbose output
  * Separate stdout/stderr in ProcessManager if possible
  * Satisfy Scrutinizer
  * Release v3.10.1
  * Set environment after running git --version
  * Pass on more options from push to activate command
  * ActivityMonitor: hide progress bar if output is not decorated (#556)
  * Ensure a fresh cache in getEnvironment() before determining nonexistence of an environment
  * Fix default service for `output`
  * Release v3.10.2
* Tue Dec 27 2016 jimmy@boombatower.com
- Update to version 3.10.0:
  * Add push command
  * Refactor custom SSH commands for Git and other uses
  * Refactor Util and Helper classes into a DIC with services
  * Attempt to ensure $_ENV and $_SERVER are populated
  * Update project:variable commands for DI
  * push command: fix extra space in Git args
  * push command: don't throw an exception if the Git command fails
  * push command: fix --force was not forwarded to git
  * Convert UrlCommandBase to Url service
  * push command: use git remote (helps for tracking)
  * Update client
  * Convert Api and cache factory to services
  * Rename CliConfig to Config service
  * Consistent interface for Table
  * Fix Filesystem arguments
  * Unnecessarily optional arguments
  * Tidy output verbosity in CommandBase
  * Convert LocalBuild to a service
  * push command: Clear environments cache on success
  * Avoid repeating an API request looking for a non-existent environment
  * Remove getHomeDir from CommandBase
  * Remove CommandBase->getSessionsDir()
  * Clear relationships cache after pushing
  * Private where possible (for now) in CommandBase
  * Restore Drush->setHomeDir() to fix tests
  * Fix Drush class for PHP <7
  * Add docblocks to all service objects
  * Fix URL openers
  * Use configureIO instead of doRun
  * Move ActivityUtil to ActivityMonitor service
  * Unused vars
  * Minor ActivityMonitor tidy
  * Clear up stderr/stdout confusion in Shell and Toolstack classes
  * Ignore SSH error after pushing
  * Rename Util -> NestedArrayUtil
  * Add test for NestedArrayUtil
  * Improve activation/parenting in push command
  * Clear environments cache after activation
  * Refactor activate-after-push
  * Fix static cache
  * Allow changing interactivity in runOtherCommand
  * Remove shebang hack for portability
  * Avoid offering to parent master
  * Remove uses of getProperty()
  * Push command: add -f, remove --dry-run
  * Show short name in examples
  * Add examples of push command
  * Release v3.10.0
* Wed Dec 14 2016 jimmy@boombatower.com
- Update to version v3.9.0:
  * multi: separate stderr and stdout
  * Make sql-dump not depend on a project root
  * Add --no-dev to composer/symfony build flavors
  * Revert "Add --no-dev to composer/symfony build flavors"
  * Flag suspended projects in the list
  * Warn about a suspended project in the welcome command.
  * Show login command for LoginRequiredException
  * Cache the list of log files
  * Release v3.8.1
  * Add a Project Variable Set command.
  * Add a Project Variable Delete command.
  * Add a Project Variable Get command.
  * Register the new Project Variable commands.
  * Exception if subscription not found
  * More generic log command autocomplete
  * Add unix shell as requirement (#545)
  * Clear the cache after a long-running activity
  * Ignore unreadable directories when searching for applications
  * Allow choosing a database via a --relationship command line option
  * Mention other build tools in README
  * Revert unnecessary RelationshipsUtil changes
  * Strip subdomains from project URLs
  * Update composer.json.
  * Release v3.9.0
- Take advantage of versionrewrite-pattern param for tar_scm to remove v prefix
  from tag to create a standard version that works better with tools.
  https://github.com/M0ses/obs-service-tar_scm/pull/1
* Thu Nov 10 2016 jimmy@boombatower.com
- Update to version v3.8.0:
  * Fix: environments url-encoded in parsed URL
  * Fixed broken environment:sql command on PostgreSQL databases. (#530)
  * Fix config for domain detection
  * Allow locating projects by ID only
  * Cache projects located by ID
  * Allow 'url' as a special property in info commands
  * Fix pldr/platform_local_drush in Bash
  * Consistent Bash quoting
  * Improve errors when no environment selected
  * Unused $message variable
  * Fix chooseDatabase() to not hardcode the relationship name
  * Create CLI command for quick-read on SQL disk usage.
  * Reduce the output to max space, used space and percent used.
  * sqls: Use Table class
  * No need to use BufferedOutput now
  * Coding standards (PSR-2 / Symfony)
  * Add help texts.
  * Find service name via relationship name in app config
  * Removed lines related to verbosity.
  * Prevent division by zero if allocated disk size could not be determined.
  * Prevent warnings when database service disk cannot be determined.
  * Add db namespace for database commands (#535)
  * Release v3.8.0
* Fri Nov  4 2016 jimmy@boombatower.com
- Update to version v3.7.1:
  * ... more specific check for Drush env var
  * Add a static cache for project config and remove indirection
  * auth:info command: property argument, and allow uuid as property
  * Ignore timeouts in project:create
  * Coding standards in ProjectCreateCommand
  * Ignore failure to download in delegated self-update
  * ... follow-up to actually ignore download failure
  * Permit a command to continue after updating (#529)
  * Release v3.7.1
* Thu Oct 27 2016 jimmy@boombatower.com
- Update to version v3.7.0:
  * Save a Git symbolic-ref command on most calls to getCurrentBranch()
  * Add --run-deploy-hooks option to build command
  * Harmonise build settings with build command options
  * Fix relevant build options for the tree id
  * Mini refactor
  * Do not back up a symlinked build directory
  * Test repeated Drupal build
  * Allow Drush location to be overridden for tests
  * Release v3.7.0
* Fri Oct 21 2016 jimmy@boombatower.com
- Update to version v3.6.0:
  * Write to .git/info/exclude more often
  * Default to NO for removing remote branch and add option to not delete
  * make sure local branch is tracking upstream on environment:branch
  * Setting the upstream after everything was created
  * Keep default to Y
  * Specify --inactive or --no-delete-branch, not both
  * Allow deleting merged and inactive envs in one command (#521)
  * Installer: avoid misleading error if $argv doesn't exist
  * Add --my filter to project:list
  * Cache the current user's account info
  * Move proc_open() logic into ShellHelper
  * Simpler output-if-verbose syntax
  * Installer: better fix for empty $argv notice
  * Show alias and executable name in command synopsis (i.e. "platform branch" instead of "environment:branch") (#526)
  * Expose current account info via auth:info command (#525)
  * Add a 'none' toolstack
  * Release v3.6.0
* Fri Oct  7 2016 jimmy@boombatower.com
- Update to version v3.5.4:
  * Additional fix for Drush and the profile directory
  * Only backup the build directory if it is a real dir
  * Release v3.5.4
* Fri Oct  7 2016 jimmy@boombatower.com
- Update to version v3.5.3:
  * Fix (again) environment URL in `web` command
  * Fix 'Remote branch  not found' regression in 'platform get' with no arguments
  * Release v3.5.3
* Thu Oct  6 2016 jimmy@boombatower.com
- Update to version v3.5.2:
  * Improve activities batch performance (#510)
  * Allow "get" command with a project URL (update for machine name)
  * Fix exception when SSH key is not found
  * Simpler check in doRun()
  * Ensure temporary directory does not exist before Drush make (#516)
  * Use starts_at in activity batching
  * Fix selectEnvironment() bug from 9049359cb2d18b57dc480578a8335e9b1dfa0144
  * Correct UI URL in 'web' command for envs with special characters
  * Release v3.5.1
  * Allow special characters in branch command
  * Improve formatting of API error details
  * Fix environment:info bug when updating the parent
  * Release v3.5.2
* Fri Sep 23 2016 jimmy@boombatower.com
- Update to version v3.5.0:
  * Add --exclude option to environment:delete
  * Remove dist/manifest.json
  * Rename to installer.php
  * Refactor environment:checkout a bit
  * Add 'title' filter to project:list (#505)
  * Add --no-backup option to build command (#504)
  * Provide an option to clone to the build directory (#475)
  * Refactor project title/id labels
  * Account for left-indented cells in adaptive table
  * .. only spaces for now
  * Add experimental plan size overrides (#508)
  * Recursively display orphaned environments (#507)
  * Simplify listProperties()
  * Update Symfony dependencies to 3.1.4
  * Release v3.5.0
* Sat Sep 10 2016 jimmy@boombatower.com
- Add source entries for files used to maintain package.
* Fri Aug 26 2016 jimmy@boombatower.com
- Update to version v3.4.1+git20160826.adf340f:
  * Update manifest for v3.4.0
  * Work around Unicode problem in branchExists()
  * Simplify branch name handling in checkout
  * Use strict in_array() for ideological correctness
  * Fix exporting a Drush alias for branch names containing '
  * Release v3.4.1
* Wed Aug 24 2016 jimmy@boombatower.com
- Update to version v3.4.0+git20160824.3d4baf5:
  * Copy install files into the repository
  * Installer: require phar, and warn about ctype
  * Add README.md to dist directory
  * Add --date-fmt option to info commands
  * Update Symfony and dev dependencies
  * Validate roles case insensitively in user:add
  * Select environments with unsanitized name first
  * Allow selecting the environment by machine_name
  * Add domain:update command
  * Add domain:get comand
  * Change default CSV/TSV and datetime formats
  * Add an interactive domain name choice
  * Simplify ssl.expires_on formatting
  * Release v3.4.0
* Wed Aug 10 2016 jimmy@boombatower.com
- Update to version v3.3.6+git20160809.d262f3f:
  * Avoid parseProjectId() on null
  * Added an editorconfig file to keep IDEs properly behaved.
  * Update dependencies. Should mitigate CVE-2016-5385 and allow PHP 7.1 support
  * Add security-checker in Travis (#482)
  * Use a direct proc_open() instead of passthru() (#484)
  * Remove extra parsing to find SSH/Drush commands (#485)
  * Release v3.3.5
  * Follow-up fix: SSH and Drush commands silently dropping arguments
  * Explicitly check the PHP version when running the CLI tool (#489)
  * Ensure the project ID is written to config after 'get'
  * Report progress during Git clone (#487)
  * No need anymore for temporary vars in the executable file
  * More reliably exclude .platform/local from Git
  * Use a separate session ID for API tokens (#492)
  * Release v3.3.6
* Fri Jul  8 2016 jimmy@boombatower.com
- Update to version v3.3.4+git20160708.06057ca:
  * Account for environments without $_ENV when loading config
  * Unused variable
  * Provide configured executable name to help instead of PHP_SELF
  * Ignore the blank lines from drush --version output
  * Fix undefined function in integration:update (issue #465)
  * Output simple table when there is no format option e.g. after integration:update
  * Release v3.2.2
  * Remove minimum Drush version check (#464)
  * Tweak to integration code style for more flexibility
  * Display fatal runtime errors by default.
  * Hide clean command; unhide dir command
  * Symlink all mounts, from the build to shared directories (#470)
  * Use chmod to force deleting builds even when files are read-only (#469)
  * Fix: --copy option caused dot files to be copied
  * Add regression test for copyAll() expanding the blacklist via fnmatch()
  * Create a settings.local.php for Drupal + Composer (#471)
  * Yaml::parse() lies about its return value being an array
  * Allow the API token to be set via a file specified in ~/.platformsh/config.yaml (#472)
  * Release v3.3.0
  * Prevent new lines messing up tokens
  * Show roles on all environments in user:role
  * Add autocompletion and other improvements for user:role
  * Fix overriding a config array with a scalar value
  * More user:role tidying
  * More efficient unprotect()
  * Docblock for Table class
  * Fix apparent bug in getProjectRoot() with legacy project structures
  * Remove vfsStream and clean up temp test dirs
  * Document user config overrides in config.yaml
  * Allow overwriting files with shared file mount symlinks
  * Use --recursive option to git clone
  * Revert "Use --recursive option to git clone" (only introduced in Git 1.6.5)
  * Make the level more obvious in user:role
  * Clean up LocalBuild settings
  * Pass verbosity on to Composer
  * Release v3.3.1
  * Report more error detail for DELETE requests
  * Suppress usage for welcome command errors
  * Correct service name for project:get with empty repo
  * Account for orphaned environments in environment:list
  * Unused import
  * Release v3.3.2
  * Fix environments duplicated in list (caused by 3b2d61238347b2cc1c614af9ca10cec902908d0d)
  * Release v3.3.3
  * Update client to fix reporting all empty responses as failure (even 200)
  * Assume Drush is installed if the command resolved (#478)
  * Release v3.3.4
* Mon Jun 13 2016 jimmy@boombatower.com
- Update to version v3.2.1+git20160613.816de17:
  * Ensure old build is removed properly
  * Tidy weird foreach() in ProcessManager
  * Improve environment:delete --merged
  * Use 'git checkout --track' in checkout command
  * GitHelper docs/test cleanup
  * Add PHP version information to the User-Agent
  * Release v3.1.2
  * Update default Drupal settings (#458)
  * Sort projects and environments (#459)
  * Add 'platform multi' command
  * Fix ArgvHelper issue when running with multi (for ssh/drush)
  * Fix doRunCommand() signature
  * Fix whether an environment is required in activity:list
  * Various sortResources() fixes
  * Allow sorting by a nested property
  * Disable some command combinations via multi
  * Git exclude info not added for empty projects
  * Always refresh environments in the 'welcome' command
  * Allow certain config to be overridden by the user
  * Add project:create command
  * Use static cache for project root when it is not found.
  * Better naming and remove NULL for $keyExists
  * ... just testing
  * Only remove the previous build when the new one completes
  * Allow the update check interval to be overridden
  * Unhide multi; remove -c alias
  * Release v3.2.0
  * Fix 'multi' command in configurations without $_ENV superglobal
  * So now $env is not needed.
  * Release v3.2.1
* Wed Jun  1 2016 jimmy@boombatower.com
- Update to version v3.1.1+git20160530.705c22c:
  + Fix drush issue (#185)
  + Fix bug in getEnvironment() (#188)
  + A further fix for getEnvironment().
  + Use HOME system variable inside double quoted PATH export
  + Call Drush with the full path to avoid a drush.bat issue on Windows.
  + Fix tar paths for Windows.
  + Fix infinite loop in getProjectRoot()
  + Hot fix - vanilla builds broken by archive behaviour
  + Follow SSH key generation with ssh-add.
  + Fix exit codes for branch
  + Hotfix: undefined variable $projectRoot
  + Temporarily remove Phar installation instructions
  + Show tunnel commands in the list; check support at 'runtime'
  + Show integration:get in the command list
  + Fix autocompletion errors
  + Fix some Scrutinizer issues
  + Remove some dead code
* Fri Mar 25 2016 jimmy@boombatower.com
- Update to 3.0.7.
* Thu Mar 24 2016 jimmy@boombatower.com
- Update to 3.0.4.
* Wed Mar 23 2016 jimmy@boombatower.com
- Update to 3.0.2.
* Tue Mar 22 2016 jimmy@boombatower.com
- Update to 3.0.0.
* Sun Mar 13 2016 jimmy@boombatower.com
- Update to 2.13.2.
- Split vendor directory instead separate tarball to allow for
  source verification.
* Wed Mar  9 2016 jimmy@boombatower.com
- Update to 2.13.1.
- Update installation of rc file for upstream renaming.
* Mon Feb 29 2016 jimmy@boombatower.com
- Update to 2.13.0.
* Wed Feb 17 2016 jimmy@boombatower.com
- Update to 2.12.3.
* Fri Feb 12 2016 jimmy@boombatower.com
- Correct liscenses.txt spelling.
- Simplify find command with -delete flag.
* Fri Feb 12 2016 jimmy@boombatower.com
- Update to 2.12.1.
* Thu Feb 11 2016 jimmy@boombatower.com
- Initial import of 2.12.0.
